# -*- coding: utf-8 -*-
from django.test import TransactionTestCase as TestCase

__all__ = ['models', 'settings', 'TestCase']

from . import models
from . import settings
